@@ -65,23 +65,23 @@ def autoflpy(input_file='Input_File.json'):
 
     # Sets  variables from the input file to be used.
     # If no log file path has been entered, go to the standard log path.
+    log_file_paths = []
     if data["log_to_xlsx_input"]["log_file_path"] != "" and os.path.exists(
-        data["log_to_xlsx_input"]["log_file_path"]) is True:
-        log_file_path = (data["log_to_xlsx_input"][
-                             "log_file_path"] + os.sep + data["log_to_xlsx_input"][
-                             "log_file_name"])
+      data["log_to_xlsx_input"]["log_file_path"]) is True:
+        for file in data["log_to_xlsx_input"]["log_file_name"].replace(" ", "").split(","):
+            log_file_paths.append(data["log_to_xlsx_input"][
+                                 "log_file_path"] + os.sep + file)
     else:
         # Creates a new directory to look for files.
         log_file_base_path = (default_storage_path + "log_files" + os.sep
                               )
-        log_file_path = (log_file_base_path + os.sep + data[
-            "log_to_xlsx_input"]["log_file_name"])
+        for file in data["log_to_xlsx_input"]["log_file_name"].replace(" ", "").split(","):
+            log_file_paths.append(log_file_base_path + os.sep + file)
         try:
             os.makedirs(log_file_base_path)
             # Raises error and gives advice on how to continue.
-            print('No log file directory was entered. A new directory has been'
-                  ' made.')
-            raise FileNotFoundError
+            raise FileNotFoundError('No log file directory was entered. A new directory has been'
+                                    ' made.')
         except OSError:
             print('Log file path found.')
             # Copies the example data file into the log storage
@@ -103,29 +103,44 @@ def autoflpy(input_file='Input_File.json'):
         except OSError:
             print("Excel folder found. Will use this folder to store generated"
                   " xlsx files.")
-
-    flight_date = data["log_to_xlsx_input"]["date"]
-    flight_number = data["log_to_xlsx_input"]["flight_number"]
-    name_generator.excel_file_name_updater(flight_date, flight_number)
+    # Formats the flight dates and flight numbers as lists and checks their length against the length of flight_dates
+    flight_dates = str(data["log_to_xlsx_input"]["date"]).replace(" ", "").split(",")
+    flight_numbers = flight_log_code.multi_string_data_formatter(data["log_to_xlsx_input"]["flight_number"],
+                                                                 flight_dates, "flight_numbers")
     # Generates an appropriate file name
-    excel_file_name = name_generator.generated_file_name
-
+    excel_file_names = name_generator.excel_file_name_updater(flight_dates, flight_numbers)
     # Imports custom weather data entered into the input file
-    weather_data = data["weather_data"]
+    weather_data_multi = data["weather_data"]
 
     # Imports custom runway data entered into the input file
-    runway_data = data["runway_data"]
+    runway_data_multi = data["runway_data"]
+    # Formats the weather data into several separate dictionaries
+    weather_data_lists = flight_log_code.multi_dictionary_data_formatter(
+        weather_data_multi, flight_dates, "weather_data")
+    # Formats the runway data into several separate dictionaries
+    runway_data_lists = flight_log_code.multi_dictionary_data_formatter(
+        runway_data_multi, flight_dates, "runway_data")
 
     # Runs the xlsx converter
-    log_to_xlsx.log_reader(log_file_path,
-                           name_converter_file_path,
-                           data_sources_path,
-                           excel_file_path,
-                           excel_file_name,
-                           flight_date,
-                           flight_number,
-                           weather_data,
-                           runway_data)
+    log_to_xlsx.log_reader_multi(log_file_paths,
+                                 name_converter_file_path,
+                                 data_sources_path,
+                                 excel_file_path,
+                                 excel_file_names,
+                                 flight_dates,
+                                 flight_numbers,
+                                 weather_data_lists,
+                                 runway_data_lists)
+
+    start_times_hours = flight_log_code.multi_string_data_formatter(
+        data["flight_log_generator_input"]["start_time_hours"], flight_dates, "start_time_hours")
+    end_times_hours = flight_log_code.multi_string_data_formatter(
+        data["flight_log_generator_input"]["end_time_hours"], flight_dates, "end_time_hours")
+    arduino_flight_data_names = flight_log_code.multi_string_data_formatter(
+        data["flight_log_generator_input"]["arduino_flight_data_name"], flight_dates, "arduino_flight_data_name")
+    flight_data_file_names = []
+    for name in excel_file_names:
+        flight_data_file_names.append(str(name) + ".xlsx")
 
     # Assigns variables - checks if any information is entered into the input
     # file for the directories before creating new directories in the current
@@ -166,7 +181,6 @@ def autoflpy(input_file='Input_File.json'):
             print("Flight log folder found. Will use this folder to store "
                   "generated flight log files.")
     flight_data_file_path = (excel_file_path + os.sep)
-    flight_data_file_name = excel_file_name + ".xlsx"
     if data["flight_log_generator_input"][
         "arduino_flight_data_file_path"] != "" and \
         os.path.exists(data["flight_log_generator_input"]
@@ -185,8 +199,6 @@ def autoflpy(input_file='Input_File.json'):
         copyfile(base_path + 'test_arduino.CSV', arduino_flight_data_file_path
                  + 'test_arduino.CSV')
 
-    arduino_flight_data_name = data["flight_log_generator_input"][
-        "arduino_flight_data_name"]
     flight_log_file_name_header = "Generated_flight_log_"
     if data["flight_log_generator_input"][
         "checklist_data_file_path"] != "" and \
@@ -212,8 +224,6 @@ def autoflpy(input_file='Input_File.json'):
                           ) is False:
             copyfile(base_path + 'Checklists_nominal.xlsx', checklist_file_path
                      + 'Checklists_nominal.xlsx')
-    start_time_hours = data["flight_log_generator_input"]["start_time_hours"]
-    end_time_hours = data["flight_log_generator_input"]["end_time_hours"]
     if data["flight_log_generator_input"][
         "metar_file_path"] != "" and \
         os.path.exists(
@@ -241,26 +251,26 @@ def autoflpy(input_file='Input_File.json'):
         copyfile(base_path + 'Your_logo_file_name_here.png',
                  images_path + 'Your_logo_file_name_here.png')
     # Finds the nearest airfield for METAR information
-    icao_airfield = nearest_ICAO_finder.icao_finder(flight_data_file_path,
-                                                    flight_data_file_name)
+    icao_airfields = nearest_ICAO_finder.multi_icao_finder(flight_data_file_path,
+                                                           flight_data_file_names, excel_file_names)
 
     # Runs the flight log generator
     flight_log_code.flight_log_maker(template_file_path,
                                      template_file_name,
                                      flight_log_file_path,
                                      flight_data_file_path,
-                                     flight_data_file_name,
+                                     flight_data_file_names,
                                      arduino_flight_data_file_path,
-                                     arduino_flight_data_name,
-                                     flight_date,
-                                     flight_number,
+                                     arduino_flight_data_names,
+                                     flight_dates,
+                                     flight_numbers,
                                      flight_log_file_name_header,
                                      checklist_file_path,
-                                     icao_airfield,
-                                     start_time_hours,
-                                     end_time_hours,
+                                     icao_airfields,
+                                     start_times_hours,
+                                     end_times_hours,
                                      metar_file_path,
-                                     weather_data, runway_data)
+                                     weather_data_lists, runway_data_lists)
 
 
 if __name__ == "__main__":
