@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
+import os
 from openpyxl import Workbook
 from openpyxl.cell import WriteOnlyCell
-import os
+
 
 
 """
@@ -17,7 +18,7 @@ Based on work done by Samuel Pearson (sp1g18@soton.ac.uk) (06-08/2019)
 
 def log_reader(log_file_path, name_converter_file_path, data_sources_path,
                excel_file_path, excel_file_name, flight_date, flight_number, weather_data, runway_data):
-    """Creates a formatted excel 95 file from a log file. """
+    """Creates a formatted excel file from a log file. """
     print('Starting log reader')
     print('Creating new work book')
     # Creates a new write only workbook for faster writing
@@ -106,8 +107,7 @@ def log_reader(log_file_path, name_converter_file_path, data_sources_path,
                                 unit = name_info[3] + "_"
                             break
                     # Creates heading from data
-                    heading = heading + "_" + unit + data[3] + "_" + \
-                        flight_date + "_Flight" + flight_number
+                    heading = heading + "_" + unit + data[3] + "_" + flight_date + "_Flight" + flight_number
 
                     # Creates the heading line
                     heading_cell = WriteOnlyCell(worksheet, value=heading)
@@ -154,4 +154,16 @@ def log_reader(log_file_path, name_converter_file_path, data_sources_path,
     print('Saving workbook')
     workbook.save(filename=(excel_file_path + os.sep
                             + excel_file_name + ".xlsx"))
-    print('Log reader finished')
+    print('Log reader finished for {}'.format(str(excel_file_name)))
+
+
+def log_reader_multi(log_file_paths, name_converter_file_path, data_sources_path,
+                     excel_file_path, excel_file_names, flight_dates, flight_numbers, weather_data_multi,
+                     runway_data_multi):
+    """Runs the log_reader for once per flight log entered in the Input_file.json"""
+    for flight in range(len(flight_numbers)):
+        print("Creating workbook for {}".format(str(excel_file_names[flight])))
+
+        log_reader(log_file_paths[flight], name_converter_file_path, data_sources_path, excel_file_path,
+                   excel_file_names[flight], flight_dates[flight], flight_numbers[flight], weather_data_multi[flight],
+                   runway_data_multi[flight])
