@@ -93,8 +93,8 @@ class TestFlightLogCode(unittest.TestCase):
         # Imports data from template.
         with open(self.base_path + 'test_Input_File.json') as file:
             self.data = json.load(file)
-        self.flight_number = self.data["log_to_xlsx_input"]["flight_number"]
-        self.flight_date = self.data["log_to_xlsx_input"]["date"]
+        self.flight_number = self.data["log_to_xlsx_input"]["flight_number"].replace(" ", "").split(",")
+        self.flight_date = self.data["log_to_xlsx_input"]["date"].replace(" ", "").split(",")
         self.template_file_path = self.base_path
         self.template_file_name = self.data["flight_log_generator_input"][
             "template_file_name"]
@@ -102,37 +102,42 @@ class TestFlightLogCode(unittest.TestCase):
             "flight_log_generator_input"]["flight_log_destination"]
         self.flight_data_file_path = self.base_path  # Path to xlsx file
         self.flight_data_file_name = "test_xlsx.xlsx"
+        self.flight_data_file_name_list = ["test_xlsx.xlsx"]
         self.arduino_flight_data_file_path = self.base_path + self.data[
             "flight_log_generator_input"]["arduino_flight_data_file_path"]
         self.arduino_flight_data_name = self.data["flight_log_generator_input"
-        ]["arduino_flight_data_name"]
+        ]["arduino_flight_data_name"].replace(" ", "").split(",")
         self.flight_log_file_name_header = "test_generated_flight_log"
         self.checklist_file_path = self.base_path
         self.start_time_hours = self.data["flight_log_generator_input"][
-            "start_time_hours"]
+            "start_time_hours"].replace(" ", "").split(",")
         self.end_time_hours = self.data["flight_log_generator_input"][
-            "end_time_hours"]
+            "end_time_hours"].replace(" ", "").split(",")
         self.metar_file_path = self.base_path + self.data[
             "flight_log_generator_input"]["metar_file_path"]
-        self.weather_data = self.data["weather_data"]
-        self.comp_data_file_path = self.flight_data_file_path + self.flight_data_file_name[:-5] + ".pkl"
-        self.weather_data = self.data["weather_data"]
-        self.runway_data = self.data["runway_data"]
+        self.comp_data_file_path = self.flight_data_file_path + "test_xlsx.pkl"
+        self.weather_data = flight_log_code.multi_dictionary_data_formatter(self.data["weather_data"], self.flight_date
+                                                                            , "weather_data")
+        self.weather_data_dict = self.data["weather_data"]
+        self.runway_data = flight_log_code.multi_dictionary_data_formatter(self.data["runway_data"], self.flight_date,
+                                                                           "runway_data")
+        self.runway_data_dict = self.data["runway_data"]
 
     def tearDown(self):
         # Removes generated flight log.
         base_path = os.path.join(os.path.dirname(__file__),
                                  "test_files") + os.sep
-        generated_file_name = base_path + \
-                              "test_generated_flight_log20190123_2.ipynb"
-        if os.path.exists(generated_file_name):
-            os.remove(generated_file_name)
+        generated_file_names = [base_path + "test_generated_flight_logtest_xlsx.ipynb", base_path +
+                               "test_generated_flight_log20190123_2.ipynb"]
+        for item in range(len(generated_file_names)):
+            if os.path.exists(generated_file_names[item]):
+                os.remove(generated_file_names[item])
 
         # Removes pickled data.
-        pickle_file_name = base_path + \
-                           "test_xlsx.pkl"
-        if os.path.exists(pickle_file_name):
-            os.remove(pickle_file_name)
+        pickle_file_names = [base_path + "test_xlsx.pkl"]
+        for item in range(len(pickle_file_names)):
+            if os.path.exists(pickle_file_names[item]):
+                os.remove(pickle_file_names[item])
 
     def test_flight_log_maker(self):
         self.ICAO_airfield = nearest_ICAO_finder.icao_finder(
@@ -142,7 +147,7 @@ class TestFlightLogCode(unittest.TestCase):
                                          self.template_file_name,
                                          self.flight_log_file_path,
                                          self.flight_data_file_path,
-                                         self.flight_data_file_name,
+                                         self.flight_data_file_name_list,
                                          self.arduino_flight_data_file_path,
                                          self.arduino_flight_data_name,
                                          self.flight_date,
@@ -157,8 +162,7 @@ class TestFlightLogCode(unittest.TestCase):
                                          self.runway_data)
         # This code tests the flight_log_maker function.
         # First, check that a file has been created.
-        test_flight_log_file_path = self.base_path + \
-                                    'test_generated_flight_log20190123_2.ipynb'
+        test_flight_log_file_path = self.base_path + 'test_generated_flight_logtest_xlsx.ipynb'
         if os.path.exists(test_flight_log_file_path) is True:
             file_exists = True
         else:
@@ -199,8 +203,8 @@ class TestFlightLogCode(unittest.TestCase):
             # Filters the checklist for the correct data
             filtered_frame = \
                 flight_log_code.checklist_finder(frame_list,
-                                                 self.flight_number,
-                                                 self.flight_date)
+                                                 self.flight_number[0],
+                                                 self.flight_date[0])
             # Check that the correct data was output
             battery_voltage = filtered_frame['Battery Voltages'][2]
             self.assertEqual('25.2', str(battery_voltage))
@@ -215,10 +219,10 @@ class TestFlightLogCode(unittest.TestCase):
         # Generates content
         content = flight_log_code.contents_opener(self.template_file_path,
                                                   self.template_file_name)
+        file_name_data = str(self.flight_date[0]) + "_" + str(self.flight_number[0])
         # Runs the flight log creator code
         flight_log_code.flight_log_creator(content, self.base_path,
-                                           self.flight_date,
-                                           self.flight_number,
+                                           file_name_data,
                                            self.flight_log_file_name_header)
         # Checks the file was created correctly
         file_exists = os.path.exists(self.base_path
@@ -237,9 +241,9 @@ class TestFlightLogCode(unittest.TestCase):
             self.checklist_file_path, "Checklists_emergency.xlsx")
         # Filters checklist for the current flight
         filtered_frame_nominal = flight_log_code.checklist_finder(
-            frame_list_nominal, self.flight_number, self.flight_date)
+            frame_list_nominal, self.flight_number[0], self.flight_date[0])
         filtered_frame_emergency = flight_log_code.checklist_finder(
-            frame_list_emergency, self.flight_number, self.flight_date)
+            frame_list_emergency, self.flight_number[0], self.flight_date[0])
         # Runs the flight_log_checklist code
         content = \
             flight_log_code.flight_log_checklist(filtered_frame_nominal,
@@ -326,8 +330,7 @@ class TestFlightLogCode(unittest.TestCase):
                            'CTUN', 'AOA', 'Action', 'ArduinoMicro']
         # Checks that the titles are present and in the correct palace
         for item in range(len(expected_titles)):
-            self.assertEqual(flight_data_and_axis[item][0],
-                             expected_titles[item])
+            self.assertEqual(expected_titles[item], flight_data_and_axis[1][item][0])
 
     def test_file_type_finder(self):
         # Detects xlsx files from the test_files folder
@@ -343,7 +346,7 @@ class TestFlightLogCode(unittest.TestCase):
 
     def test_compile_and_compress(self):
         # Runs the compiler and compressor.
-        flight_log_code.compile_and_compress(self.flight_data_file_path, self.flight_data_file_name,
+        flight_log_code.compile_and_compress(self.flight_data_file_path, [self.flight_data_file_name],
                                              self.arduino_flight_data_file_path, self.arduino_flight_data_name,
                                              self.comp_data_file_path)
         pickle_file_name = self.base_path + "test_xlsx.pkl"  # Defines the file name
@@ -352,9 +355,9 @@ class TestFlightLogCode(unittest.TestCase):
 
     def test_dictionary_reader(self):
         # Returns a string of formatted weather data
-        read_data = flight_log_code.dictionary_reader(self.weather_data, units_present=True)
+        read_data = flight_log_code.dictionary_reader(self.weather_data_dict, units_present=True)
         # Adds a string of formatted runway data
-        read_data += flight_log_code.dictionary_reader(self.runway_data, units_present=False)
+        read_data += flight_log_code.dictionary_reader(self.runway_data_dict, units_present=False)
         expected_results = ["Action time : 12:34 hh:mm", "Pressure : 1234567 Pa", "Temperature : -12.3 C",
                             "Wind direction : 123 degrees", "Wind speed : 12.3 mps", "take off direction : 321",
                             "runway surface : XYZ", "surface condition : ZYX"]
