@@ -14,8 +14,8 @@ class TestNameGenerator(unittest.TestCase):
 
     def setUp(self):
         # Defines variables needed
-        self.date = 12345678
-        self.flight_number = 2
+        self.date = [12345678]
+        self.flight_number = [2]
 
     def test_name_generator(self):
         # Runs the name generator code
@@ -23,7 +23,7 @@ class TestNameGenerator(unittest.TestCase):
         # Assigns expected outcome
         expected_name = '12345678_Flight02'
         # Checks that the expected outcome is as expected
-        self.assertEqual(expected_name, name_generator.generated_file_name)
+        self.assertEqual(expected_name, name_generator.generated_file_name[0])
 
 
 if __name__ == '__main__':
